LCWAInstances
=============

.. currentmodule:: pykeen.triples

.. autoclass:: LCWAInstances
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LCWAInstances.from_triples

   .. rubric:: Methods Documentation

   .. automethod:: from_triples
